@@ -188,7 +188,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         :var password: Password for authentication.
         """
         username = username if username else ''
-        password = username if password else ''
+        password = password if password else ''
         await self.send_peer_properties()
         await self.send_sasl_handshake()
 
